.. _examples:

********
Examples
********

We implemented a few examples to display how Dune-MMesh can be used in different contexts.

.. toctree::
  :maxdepth: 1

  examples/coupling
  examples/moving
  examples/manual
  examples/mixeddim
  examples/poroelasticity
  examples/twophase

All examples can be found in the directory `doc/examples` as IPython notebooks.

Some examples for the creation of grid files can be found in :ref:`grids`.

.. toctree::
  :maxdepth: 1
  :hidden:

  examples/grids/grids
